@@ -11,10 +11,14 @@ import n_gram
 import rec10d
 import ts2epg
 import xml2db
+import configreader
+import recdblist
 path = str(os.path.dirname(os.path.abspath(__file__))) + "/"
-tmppath = path
+tmppath = configreader.getpath("tmp")+"/"
+if tmppath=="/":
+    tmppath=path
 def update(chtxt):
-    print chtxt
+    recdblist.printutf8(chtxt)
     tnow = datetime.datetime.now()
     try:
         lastup = datetime.datetime.strptime(chdb.chtxtsearch(chtxt)[0]['update'], "%Y-%m-%d %H:%M:%S")
@@ -23,48 +27,27 @@ def update(chtxt):
     dt = tnow-lastup
     dt = dt.days * 24 * 60 + dt.seconds
     if dt > 2 * 60 * 60:
-        ts2epg.write(tmppath + chtxt + "epgdate.xml", chdb.chtxtsearch(chtxt)['ch'])
-        xml2db.xml2db(tmppath + chtxt + "epgdate.xml", chdb.chtxtsearch(chtxt)['bctype'])
+        ts2epg.write(tmppath + chtxt + "epgdata.xml", chdb.chtxtsearch(chtxt)['ch'])
+        xml2db.xml2db(tmppath + chtxt + "epgdata.xml", chdb.chtxtsearch(chtxt)['bctype'])
 def updatebc(bctype):
     bctypel = chdb.bctypesearch(bctype)
-    print bctypel
+    print bctype
     try:
-        ts2epg.write(tmppath + bctype + "epgdate.xml", chdb.bctypesearch(bctype)['ch'])
-        xml2db.xml2db(tmppath + bctype + "epgdate.xml", bctype)
-        shutil.copyfile(tmppath + bctype + "epgdate.xml", tmppath + bctype + "epgdate.bak.xml")
-        rec10d.rec10db.update_by_bctype_chdata(bctype)
+        ts2epg.write(tmppath + bctype + "epgdata.xml", chdb.bctypesearch(bctype)['ch'])
+        xml2db.xml2db(tmppath + bctype + "epgdata.xml", bctype)
+        shutil.copyfile(tmppath + bctype + "epgdata.xml", tmppath + bctype + "epgdata.bak.xml")
+        rec10d.rec10db.update_by_bctype_epg_ch(bctype)
     except Exception, inst:
+        print "error occurs in updatebc(epgdb)"
         print type(inst)
         print inst
-        xml2db.xml2db(tmppath + bctype + "epgdate.bak.xml", bctype)
-        rec10d.rec10db.update_status_by_bctype_chdata(bctype, "2")
+        xml2db.xml2db(tmppath + bctype + "epgdata.bak.xml", bctype)
+        rec10d.rec10db.update_status_by_bctype_epg_ch(bctype, "2")
 def updatebc_bak(bctype):
     """
     update epg data by .bak file
     """
-    xml2db.xml2db(tmppath + bctype + "epgdate.bak.xml", bctype)
-def updateall_bak():
-    updatebc_bak("te13")
-    updatebc_bak("te20")
-    updatebc_bak("te22")
-    updatebc_bak("te18")
-    updatebc_bak("te19")
-    updatebc_bak("te21")
-    updatebc_bak("te23")
-    updatebc_bak("cs1")
-    updatebc_bak("cs2")
-    updatebc_bak("bs")
-def updateall():
-    updatebc("te13")
-    updatebc("te20")
-    updatebc("te22")
-    updatebc("te18")
-    updatebc("te19")
-    updatebc("te21")
-    updatebc("te23")
-    updatebc("cs1")
-    updatebc("cs2")
-    updatebc("bs")
+    xml2db.xml2db(tmppath + bctype + "epgdata.bak.xml", bctype)
 def searchtime2(titletxt, timet, deltatime, chtxt):
     time = datetime.datetime.strptime(timet, "%Y-%m-%d %H:%M:%S")
     ret = []
@@ -74,9 +57,9 @@ def searchtime2(titletxt, timet, deltatime, chtxt):
     aftertime = aftertime.strftime("%Y%m%d%H%M%S")
     one = ["", "", "", ""]
     tempt = 0
-    d = rec10d.rec10db.select_by_time_ngram_tv(beforetime, aftertime, chtxt)
-    for chtxtt, title, start, stop in d:
-        #print chtxtt+":"+title+":"+start+":"+stop
+    d = rec10d.rec10db.select_by_time_ngram_epg_timeline(beforetime, aftertime, chtxt)
+    for chtxtt, title, start, stop ,exp,longexp,category in d:
+        #recdblist.printutf8(chtxtt+":"+title+":"+start+":"+stop)
         p = n_gram.bigram(titletxt, title)
         btime = start
         btime = btime[0:4] + "-" + btime[4:6] + "-" + btime[6:8] + " " + btime[8:10] + ":" + btime[10:12] + ":00"
@@ -89,12 +72,26 @@ def searchtime2(titletxt, timet, deltatime, chtxt):
         dt = 1000-1000 * dt / (7 * 24 * 60 * 60)
         if p > 0:
             p = p + dt
-            print dt
         if p > tempt:
-            one = [chtxtt, title.encode('utf-8'), btime, etime]
+            one = [chtxtt, title, btime, etime,exp,longexp,category]
             tempt = p
         if p > 0:
-            print title + ":" + str(p) + "点"
+            recdblist.printutf8(title + ":" + str(p) + u"点")
     ret = one
     print ret
     return ret
+def searchtime_auto(keytxt, timet, deltatime):
+    time = datetime.datetime.strptime(timet, "%Y-%m-%d %H:%M:%S")
+    ret = []
+    deltatime = int(deltatime)
+    beforetime = time.strftime("%Y%m%d%H%M%S")
+    aftertime = time + datetime.timedelta(hours=deltatime)
+    aftertime = aftertime.strftime("%Y%m%d%H%M%S")
+    d = rec10d.rec10db.select_by_time_auto_suggest_epg_timeline(keytxt,beforetime, aftertime)
+    for chtxtt, title, start, stop ,exp,longexp,category in d:
+        btime = start
+        btime = btime[0:4] + "-" + btime[4:6] + "-" + btime[6:8] + " " + btime[8:10] + ":" + btime[10:12] + ":00"
+        etime = stop
+        etime = etime[0:4] + "-" + etime[4:6] + "-" + etime[6:8] + " " + etime[8:10] + ":" + etime[10:12] + ":00"
+        ret.append([chtxtt, title, btime, etime,exp,longexp,category])
+    return ret
\ No newline at end of file
