@@ -2,9 +2,7 @@
 # coding: UTF-8
 # Rec10 TS Recording Tools
 # Copyright (C) 2009 Yukikaze
-import timerec
 import chdata
-import epgdb
-chdata
-timerec.task()
-#epgdb.updateall_bak()
\ No newline at end of file
+import timerec
+chdata.new_chdata()
+timerec.task()
\ No newline at end of file
