@@ -6,11 +6,9 @@ import commands
 import os
 import re
 import time
-import base64
 import tv2avi
+import recdblist
 def ts2x264(pin, pout, opts):#sizeは"HD"か"SD"
-    pout = pout.encode('utf-8')
-    pin = pin.encode('utf-8')
     """
     pinで指定されたファイルをpoutにx264でエンコードして書き出す
     """
@@ -37,9 +35,9 @@ def encode(pin,pout,size,isAnime,is2pass):
     encvf=""
     txt=""
     if isAnime == 1:
-        encvf = "-vf pullup,softskip,pp=l5,"
+        encvf = "-vf yadif=0,"
     else:
-        encvf = "-vf pp=l5,"
+        encvf = "-vf yadif=0,"
     if size == "HD":
         encvf = encvf + "scale=1280:720,harddup"
         bitrate = "bitrate=" + tv2avi.Bitrate_HD
@@ -59,20 +57,20 @@ def encode(pin,pout,size,isAnime,is2pass):
         encvf = encvf + "scale=1280:720,harddup"
         bitrate = "bitrate=" + tv2avi.Bitrate_HD
     if is2pass == 1:
-        pas1exe = "mencoder \'" + pin + "\' -quiet -ovc x264 " + encvf + " -x264encopts " + bitrate + ":threads=auto:pass=1:turbo=2 -passlogfile \'" + pin + ".log\' " + "-oac mp3lame -lameopts cbr:br=128 -o /dev/null"
-        pas2exe = "mencoder \'" + pin + "\' -quiet -ovc x264 " + encvf + " -x264encopts " + bitrate + ":threads=auto:pass=2 -passlogfile \'" + pin + ".log\' " + "-oac mp3lame -lameopts cbr:br=128 -o \'" + pout + "\'"
+        pas1exe = "mencoder \'" + pin + "\' -quiet -ovc x264 " + encvf + " -ofps 30000/1001 -x264encopts " + bitrate + ":threads=auto:pass=1:turbo=2 -passlogfile \'" + pin + ".log\' " + "-oac mp3lame -lameopts cbr:br=128 -o /dev/null"
+        pas2exe = "mencoder \'" + pin + "\' -quiet -ovc x264 " + encvf + " -ofps 30000/1001 -x264encopts " + bitrate + ":threads=auto:pass=2 -passlogfile \'" + pin + ".log\' " + "-oac mp3lame -lameopts cbr:br=128 -o \'" + pout + "\'"
         pas1exe = "nice -n 19 " + pas1exe
         pas2exe = "nice -n 19 " + pas2exe
-        print pas1exe
-        txt=txt+commands.getoutput(pas1exe)
-        print pas2exe
+        recdblist.printutf8(pas1exe)
+        txt=txt+unicode(commands.getoutput(pas1exe.encode('utf-8')),'utf-8')
+        recdblist.printutf8(pas2exe)
         time.sleep(5)
-        txt=txt+commands.getoutput(pas2exe)
+        txt=txt+unicode(commands.getoutput(pas2exe.encode('utf-8')),'utf-8')
     else:
-        pas1exe = "mencoder \'" + pin + "\' -quiet -ovc x264 " + encvf + " -x264encopts " + bitrate + ":threads=auto -oac mp3lame -lameopts cbr:br=128  -o \'" + pout + "\'"
+        pas1exe = "mencoder \'" + pin + "\' -quiet -ovc x264 " + encvf + " -ofps 30000/1001 -x264encopts " + bitrate + ":threads=auto -oac mp3lame -lameopts cbr:br=128  -o \'" + pout + "\'"
         pas1exe = "nice -n 19 " + pas1exe
-        print pas1exe
-        txt=txt+commands.getoutput(pas1exe)
+        recdblist.printutf8(pas1exe)
+        txt=txt+unicode(commands.getoutput(pas1exe.encode('utf-8')),'utf-8')
     logo=pin
     logo=logo.replace(".sa.avi",".ts")
     logo=logo.replace(".ts",".log")
@@ -88,5 +86,5 @@ def encode(pin,pout,size,isAnime,is2pass):
         s=s+len("\n")
         stxt=stxt[s:]
     txt="\n####mencoder-log_"+size+"####\n"+stxt
-    f.write(txt)
+    f.write(txt.encode('utf-8'))
     f.close()
\ No newline at end of file
