@@ -3,6 +3,7 @@
 # Rec10 TS Recording Tools
 # Copyright (C) 2009 Yukikaze
 
+import recdblist
 global z_ascii
 global h_ascii
 global z_number
@@ -35,4 +36,22 @@ def toHankaku_ABC123(str):
             s = h_number[i]
         retstr = retstr + s
     return retstr
-
+def check_Character_Type(character):
+    """
+    return code is 1:Alphabet 2:Hiragana 3:Katakana 4:Kanji
+    """
+    #recdblist.printutf8(character)
+    #recdblist.printutf8(type(character))
+    #character=character.encode('UTF-8')
+    #recdblist.printutf8(character)
+    #recdblist.printutf8(type(character))
+    chcode=ord(character)
+    #recdblist.printutf8(ord(chcode))
+    if chcode>=0x0000 and chcode<=0x007F:
+        return 1
+    elif chcode>=0x3040 and chcode<=0x309F:
+        return 2
+    elif chcode>=0x30A0 and chcode<=0x30FF:
+        return 3
+    elif chcode>=0x4E00 and chcode<=0x9FFF:
+        return 4
\ No newline at end of file
